/*
 * The MIT License
 *
 * Copyright (c) 2013, Frederic Gurr
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package jenkins.plugins.extracolumns;

import org.kohsuke.stapler.DataBoundConstructor;

import hudson.Extension;
import hudson.matrix.MatrixProject;
import hudson.model.ViewJob;
import hudson.model.AbstractProject;
import hudson.model.FreeStyleProject;
import hudson.model.Job;
import hudson.views.ListViewColumn;
import hudson.views.ListViewColumnDescriptor;

public class JobTypeColumn extends ListViewColumn {

    @DataBoundConstructor
    public JobTypeColumn() {
        super();
    }

    public String getJobType(@SuppressWarnings("rawtypes") Job job) {
       if(job instanceof AbstractProject){
            AbstractProject project = (AbstractProject) job;
            //checking simple name avoids having dependencies on plugins
            if("MavenModuleSet".equals(job.getClass().getSimpleName())){
                return Messages.JobTypeColumn_MavenName();
            }else if("MultiJobProject".equals(job.getClass().getSimpleName())){
                return Messages.JobTypeColumn_MultiJobName();
            }else if("IvyModuleSet".equals(job.getClass().getSimpleName())){
                return Messages.JobTypeColumn_IvyName();
            }else if(project instanceof MatrixProject){
                return Messages.JobTypeColumn_MultiConfigName();
            }else if(project instanceof FreeStyleProject){
                return Messages.JobTypeColumn_FreestyleName();
            }
        }else if(job instanceof ViewJob){
            return Messages.JobTypeColumn_ExternalName();
        }
        return "";
    }

    @Extension
    public static class DescriptorImpl extends ListViewColumnDescriptor {

        public DescriptorImpl() {
        }

        @Override
        public String getDisplayName() {
            return Messages.JobTypeColumn_DisplayName();
        }

        public boolean shownByDefault() {
            return false;
        }

    }

}
